@@ -70,8 +70,11 @@ def to_csv_by_line(filename: str, data: list):
 
 def ensure_lnglat(df) -> pd.DataFrame:
     '''将df中的经纬度重命名为lng和lat'''
+    from warnings import warn
     from ricco import to_lnglat_dict
     df.rename(columns=to_lnglat_dict, inplace=True)
+    if ('lng' not in df.columns) or ('lat' not in df.columns):
+        warn('转换失败，输出结果无lng或lat字段')
     return df
 
 
@@ -136,70 +139,6 @@ def split_csv(filename: str, n: int = 5, encoding: str = 'utf-8'):
         add.to_csv(savefile, index=0, encoding=encoding)
 
 
-def valid_check(polygon_geom):
-    '''检验面的有效性'''
-    from shapely.wkb import loads
-    df = polygon_geom.copy()
-    if len(df[df['geometry'].isna()]) > 0:
-        raise ValueError('geometry中有空值，请检查')
-    df['geometry'] = df['geometry'].apply(lambda x: loads(x, hex=True))
-    df = gpd.GeoDataFrame(df)
-    df.crs = 'epsg:4326'
-    df['flag'] = df['geometry'].apply(lambda x: 1 if x.is_valid else -1)
-    if len(df[df['flag'] < 0]) == 0:
-        print('Validity test passed.')
-    else:
-        raise Exception('有效性检验失败，请检查并修复面')
-
-
-def _dumps(x, hex=True, srid=4326):
-    from shapely.wkb import dumps
-    try:
-        x = dumps(x, hex=hex, srid=srid)
-    except AttributeError:
-        x = None
-    return x
-
-
-def shp2csv(shpfile_name: str, encoding='utf-8'):
-    '''shapefile 转 csv 文件'''
-    df = rdf(shpfile_name)
-    print(df.head())
-    df = gpd.GeoDataFrame(df)
-    df['geometry'] = df['geometry'].apply(lambda x: _dumps(x, hex=True, srid=4326))
-    df.crs = 'epsg:4326'
-    save_path = fn(shpfile_name) + '.csv'
-    print(df.head())
-    df.to_csv(save_path, encoding=encoding, index=False)
-
-
-def _loads(x, hex=True):
-    from shapely.wkb import loads
-    try:
-        x = loads(x, hex=hex)
-    except AttributeError:
-        x = None
-    return x
-
-
-def csv2shp(filename: str):
-    '''csv文件 转 shapefile'''
-    import fiona
-    df = rdf(filename)
-    df = df.rename(columns={'名称': 'name',
-                            'geom': 'geometry'})
-    df = gpd.GeoDataFrame(df)
-    df['geometry'] = df['geometry'].apply(lambda x: _loads(x, hex=True))
-    df.crs = 'epsg:4326'
-    save_path = fn(filename) + '.shp'
-    try:
-        df.to_file(save_path, encoding='utf-8')
-    except fiona.errors.SchemaError:
-        df.columns = [pinyin(i) for i in df.columns]
-        df.to_file(save_path, encoding='utf-8')
-        print('已将列名转为汉语拼音进行转换')
-
-
 def per2float(string: str) -> float:
     if '%' in string:
         string = string.replace('%', '')
@@ -390,10 +329,131 @@ def fuzz_df(df: pd.DataFrame,
     :param target_serise: 从何处匹配， list/pd.Serise
     :return:
     '''
-    df[[col + '_target',
+    df[[f'{col}_target',
         'normal_score',
-        'partial_score']] = df.apply(lambda x:
-                                     fuzz_match(x[col], target_serise),
-                                     result_type='expand',
-                                     axis=1)
+        'partial_score']] = df.apply(lambda x: fuzz_match(x[col], target_serise),
+                                     result_type='expand', axis=1)
+    return df
+
+
+# 地理处理
+def valid_check(polygon_geom):
+    '''检验面的有效性'''
+    from shapely.wkb import loads
+    df = polygon_geom.copy()
+    if len(df[df['geometry'].isna()]) > 0:
+        raise ValueError('geometry中有空值，请检查')
+    df['geometry'] = df['geometry'].apply(lambda x: loads(x, hex=True))
+    df = gpd.GeoDataFrame(df)
+    df.crs = 'epsg:4326'
+    df['flag'] = df['geometry'].apply(lambda x: 1 if x.is_valid else -1)
+    if len(df[df['flag'] < 0]) == 0:
+        print('Validity test passed.')
+    else:
+        raise Exception('有效性检验失败，请检查并修复面')
+
+
+def _loads(x, hex=True):
+    from shapely.wkb import loads
+    try:
+        x = loads(x, hex=hex)
+    except AttributeError:
+        x = None
+    return x
+
+
+def _dumps(x, hex=True, srid=4326):
+    from shapely.wkb import dumps
+    try:
+        x = dumps(x, hex=hex, srid=srid)
+    except AttributeError:
+        x = None
+    return x
+
+
+def shp2csv(shpfile_name: str, encoding='utf-8'):
+    '''shapefile 转 csv 文件'''
+    df = rdf(shpfile_name)
+    print(df.head())
+    df = gpd.GeoDataFrame(df)
+    df['geometry'] = df['geometry'].apply(lambda x: _dumps(x, hex=True, srid=4326))
+    df.crs = 'epsg:4326'
+    save_path = fn(shpfile_name) + '.csv'
+    print(df.head())
+    df.to_csv(save_path, encoding=encoding, index=False)
+
+
+def csv2shp(filename: str):
+    '''csv文件 转 shapefile'''
+    import fiona
+    df = rdf(filename)
+    df = df.rename(columns={'名称': 'name',
+                            'geom': 'geometry'})
+    df = gpd.GeoDataFrame(df)
+    df['geometry'] = df['geometry'].apply(lambda x: _loads(x, hex=True))
+    df.crs = 'epsg:4326'
+    save_path = fn(filename) + '.shp'
+    try:
+        df.to_file(save_path, encoding='utf-8')
+    except fiona.errors.SchemaError:
+        df.columns = [pinyin(i) for i in df.columns]
+        df.to_file(save_path, encoding='utf-8')
+        print('已将列名转为汉语拼音进行转换')
+
+
+def geom_wkb2lnglat(df, geometry='geometry', delete=False):
+    '''geometry转经纬度，求中心点经纬度'''
+    df = gpd.GeoDataFrame(df)
+    df[geometry] = df[geometry].apply(lambda x: _loads(x, hex=True))
+    df.crs = 'epsg:4326'
+    df['lng'] = df.centroid.x
+    df['lat'] = df.centroid.y
+    if delete:
+        df.drop(geometry, axis=1, inplace=True)
+    else:
+        df[geometry] = df[geometry].apply(lambda x: _dumps(x, hex=True, srid=4326))
+    return df
+
+
+def geom_wkt2wkb(df, geometry='geometry'):
+    '''wkb转wkt'''
+    from shapely import wkt
+    from shapely import wkb
+    df = gpd.GeoDataFrame(df)
+    df[geometry] = df[geometry].apply(lambda x: wkt.loads(x))
+    df.crs = 'epsg:4326'
+    df[geometry] = df[geometry].apply(lambda x: wkb.dumps(x, hex=True, srid=4326))
+    return df
+
+
+def point_to_geo(df, lng, lat, delt=1):
+    '''包含经纬度的DataFrame转GeoDataFrame'''
+    from geopandas import points_from_xy
+    df = gpd.GeoDataFrame(df, geometry=points_from_xy(df[lng], df[lat]))
+    df.crs = 'epsg:4326'
+    if delt == 1:
+        del df[lng]
+        del df[lat]
+    return df
+
+
+def point_to_geo_old(df, lng, lat, delt=1):
+    '''包含经纬度的DataFrame转GeoDataFrame'''
+    from shapely.geometry import Point
+    df['geometry'] = gpd.GeoSeries(list(zip(df[lng], df[lat]))).apply(Point)
+    df = gpd.GeoDataFrame(df)
+    df.crs = 'epsg:4326'
+    if delt == 1:
+        del df[lng]
+        del df[lat]
+    return df
+
+
+def lnglat2geom(df, lng='lng', lat='lat', delete=False):
+    '''经纬度转wkb格式的geometry'''
+    df = ensure_lnglat(df)
+    df = point_to_geo(df, lng, lat, delt=0)
+    df['geometry'] = df['geometry'].apply(lambda x: _dumps(x, hex=True, srid=4326))
+    if delete:
+        df.drop(['lng', 'lat'], axis=1, inplace=True)
     return df
